Extending fib-o-mat
===================

fib-o-mat is written in a way to make it easily extendable.
This section shows examples how various customization can be implemented.


.. toctree::
    :maxdepth: 4
    :glob:
    :hidden:

    extending/*




